@@ -2,23 +2,31 @@ package Test::Pretty;
 use strict;
 use warnings;
 use 5.010001;
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use Test::Builder;
 use Term::Encoding ();
 use File::Spec ();
 use Term::ANSIColor qw/colored/;
+use Test::More ();
 use Scope::Guard;
 use Carp ();
 
 use Cwd ();
+
+my $SHOW_DUMMY_TAP;
+my $TERM_ENCODING = Term::Encoding::term_encoding();
+my $ENCODING_IS_UTF8 = $TERM_ENCODING =~ /^utf-?8$/i;
+
 our $BASE_DIR = Cwd::getcwd();
 my %filecache;
 my $get_src_line = sub {
     my ($filename, $lineno) = @_;
     $filename = File::Spec->rel2abs($filename, $BASE_DIR);
+    # read a source as utf-8... Yes. it's bad. but works for most of users.
+    # I may need to remove binmode for STDOUT?
     my $lines = $filecache{$filename} ||= do {
-        open my $fh, '<', $filename;
+        open my $fh, "<:encoding(utf-8)", $filename;
         [<$fh>]
     };
     my $line = $lines->[$lineno-1];
@@ -26,9 +34,7 @@ my $get_src_line = sub {
     return $line;
 };
 
-my $SHOW_DUMMY_TAP;
-
-if ((!$ENV{HARNESS_ACTIVE} || $ENV{PERL_TEST_PRETTY_ENABLED}) && $^O ne 'MSWin32') {
+if ((!$ENV{HARNESS_ACTIVE} || $ENV{PERL_TEST_PRETTY_ENABLED})) {
     # make pretty
     no warnings 'redefine';
     *Test::Builder::subtest = \&_subtest;
@@ -36,6 +42,7 @@ if ((!$ENV{HARNESS_ACTIVE} || $ENV{PERL_TEST_PRETTY_ENABLED}) && $^O ne 'MSWin32
     *Test::Builder::done_testing = sub {
         # do nothing
     };
+    *Test::Builder::skip = \&_skip;
 
     my %plan_cmds = (
         no_plan     => \&Test::Builder::no_plan,
@@ -67,10 +74,9 @@ if ((!$ENV{HARNESS_ACTIVE} || $ENV{PERL_TEST_PRETTY_ENABLED}) && $^O ne 'MSWin32
     $builder->no_ending(1);
     $builder->no_header(1); # plan
 
-    my $encoding = Term::Encoding::term_encoding();
-    binmode $builder->output(), "encoding($encoding)";
-    binmode $builder->failure_output(), "encoding($encoding)";
-    binmode $builder->todo_output(), "encoding($encoding)";
+    binmode $builder->output(), "encoding($TERM_ENCODING)";
+    binmode $builder->failure_output(), "encoding($TERM_ENCODING)";
+    binmode $builder->todo_output(), "encoding($TERM_ENCODING)";
 
     if ($ENV{HARNESS_ACTIVE}) {
         $SHOW_DUMMY_TAP++;
@@ -82,18 +88,26 @@ if ((!$ENV{HARNESS_ACTIVE} || $ENV{PERL_TEST_PRETTY_ENABLED}) && $^O ne 'MSWin32
 
     $|++;
 
-    my $encoding = Term::Encoding::term_encoding();
     my $builder = Test::Builder->new;
-    binmode $builder->output(), "encoding($encoding)";
-    binmode $builder->failure_output(), "encoding($encoding)";
-    binmode $builder->todo_output(), "encoding($encoding)";
+    binmode $builder->output(), "encoding($TERM_ENCODING)";
+    binmode $builder->failure_output(), "encoding($TERM_ENCODING)";
+    binmode $builder->todo_output(), "encoding($TERM_ENCODING)";
+
+    my ($arrow_mark, $failed_mark);
+    if ($ENCODING_IS_UTF8) {
+        $arrow_mark = "\x{bb}";
+        $failed_mark = " \x{2192} ";
+    } else {
+        $arrow_mark = ">>";
+        $failed_mark = " x ";
+    }
 
     *Test::Builder::subtest = sub {
         push @NAMES, $_[1];
         my $guard = Scope::Guard->new(sub {
             pop @NAMES;
         });
-        $_[0]->note(colored(['cyan'], "\x{bb}" x (@NAMES*2)) . " " . join(colored(['yellow'], " \x{2192} "), $NAMES[-1]));
+        $_[0]->note(colored(['cyan'], $arrow_mark x (@NAMES*2)) . " " . join(colored(['yellow'], $failed_mark), $NAMES[-1]));
         $_[2]->();
     };
     *Test::Builder::ok = sub {
@@ -110,7 +124,8 @@ if ((!$ENV{HARNESS_ACTIVE} || $ENV{PERL_TEST_PRETTY_ENABLED}) && $^O ne 'MSWin32
 
 END {
     my $builder = Test::Builder->new;
-    if ($SHOW_DUMMY_TAP) {
+    my $real_exit_code = $?;
+    if ($SHOW_DUMMY_TAP && !$real_exit_code) {
         printf("\n%s\n", $builder->is_passing ? 'ok' : 'not ok');
         if ($builder->is_passing) {
             ## no critic (Variables::RequireLocalizedPunctuationVars)
@@ -173,12 +188,15 @@ ERR
     my $out;
     my $result = &Test::Builder::share( {} );
 
+
     unless($test) {
-        $out .= colored(['red'], "\x{2716}");
+        my $fail_char = $ENCODING_IS_UTF8 ? "\x{2716}" : "x";
+        $out .= colored(['red'], $fail_char);
         @$result{ 'ok', 'actual_ok' } = ( ( $self->in_todo ? 1 : 0 ), 0 );
     }
     else {
-        $out .= colored(['green'], "\x{2713}");
+        my $success_char = $ENCODING_IS_UTF8 ? "\x{2713}" : "o";
+        $out .= colored(['green'], $success_char);
         @$result{ 'ok', 'actual_ok' } = ( 1, $test );
     }
 
@@ -246,6 +264,27 @@ sub _subtest {
     $code->();
 }
 
+sub _skip {
+    my ($self, $why) = @_;
+
+    lock( $self->{Curr_Test} );
+    $self->{Curr_Test}++;
+
+    $self->{Test_Results}[ $self->{Curr_Test} - 1 ] = &Test::Builder::share(
+        {
+            'ok'      => 1,
+            actual_ok => 1,
+            name      => '',
+            type      => 'skip',
+            reason    => $why,
+        }
+    );
+
+    $self->_print(colored(['yellow'], 'skip') . " $why");
+
+    return 1;
+}
+
 1;
 __END__
 
